@@ -1,54 +1,69 @@
 import inspect
 import os
-# 
 import sys
+#시스템 아웃풋을 없게 한다
 sys.tracebacklimit = 0
+#이벤트 분류를 할 때 사용한다.
 global Event_name
 Event_name = ''
-global long
-long = 0
-global comnum
-comnum = 0
+#에러가 있다면 몇줄에 있는지
+global whenerror
+whenerror = 0
+#command가 들어가 있는지 여부 판단
+global command_contain
+command_contain = 0
+#repeat을 할 떄 list의 종류를 차례로 받는것이다.
 global list_name_list
 list_name_list = []
+#부득이 하게 자료형을 변환해야 할떄 쓰는 리스트
 global type_list
 type_list = []
+#메인. 행동에 대해 분류하는 리스트다.
 global check_list
 check_list = []
+#들여쓰기를 위해 만든 변수. 이 변수를 통해 연산자의 끝나는 위치를 찾는데도 활용된다.
 global python_space
 python_space = 0
-global test_value
-test_value = 0
+#event의 개수에 따라 함수가 겹치지 않게 만들어 주는 변수
+global event_value
+event_value = 0
+#변수에 이름이 key,변수값이 value인 dictionary
 global var_dict
 var_dict = {}
+#import package를 추가하는 리스트
 global addition_list
 addition_list = []
-global howmany
-howmany = -1
-python_var = 0
-global n
-n = 0
-global k
-k = 0
-global var_dict_type
-var_dict_type = {"ArrayList":False,"Material":False,"Player":False,"Inventory":False,"World":False,"Location":False,"Block":False,"ItemStack":False,"Action":False}
+#command문을 적을 떄 return false가 필요한지 물어보는 문제
+global isreturnneed
+isreturnneed = -1
+#반복할 때 필요한 변수. 한번 돌고 나오도록 만들어주는 코드이다.
+global repeat_var
+repeat_var = 0
+#if를 사용 할 떄 필요한 변수. 한번 돌고 나오도록 만들어주는 코드이다.
+global when_var
+when_var = 0
+#변수가 이미 선언되었는지 필요한 리스트 없다면 코드를 자동 선언해준다
 global var_list
 var_list = []
-global check_list_var
-check_list_var = 0
+#메인2.자바의 쓸 코드를 실질적 string에 저장해주는 곳.
 global javacode
 javacode = ''
-global java_space
-java_space = 0
-global Playerinclude
-Playerinclude =False
+#range는 range만의 알고리즘이 필요하기 때문에, for_range라는 이름으로 행동을 분류하였다.
 def range(first,second):
     global check_list
     check_list.append("for_range")
-    return [1]
+    return [1] #아무값이나 넣어줌(힌번만 돌게)
+class time:
+    def sleep(second):
+        global check_list
+        check_list.append("activity")
+#random값을 넣게 되면 python자체 값으로 돌아가므로 java값을 만들기 위해 random 클래스를 만듬(물론 randint만 필요)
 class random:
     def randint(first,second):
         pass
+#자동으로 변수를 선언 해주는 함수이다.
+#m에 type에 맞는 code를 만들어
+#javacode에 추가해준다.
 def define_auto(code):
     var_name = code.split("=")[0]
     global var_dict_type
@@ -57,7 +72,7 @@ def define_auto(code):
     global javacode
     m = ''
     if not var_list.__contains__(var_name):
-        data = code.split("=")[1]
+        var_list.append(var_name)
         code1 = code.split(".")[-1]
         if code1.__contains__("size"):
             code1 = code.split(".")[-2]
@@ -65,7 +80,6 @@ def define_auto(code):
             code1 = code
         code = code1
         type_Var = ""
-        m = ''
         code = code.replace(" ","")
         if code.__contains__('getPlayer') or code.__contains__('sender'):
             type_Var = "Player"
@@ -92,7 +106,7 @@ def define_auto(code):
             type_Var = "Block"
             m = 'public Block '+var_name+" = new Block();;\n"
         elif code.__contains__('getMaterial'):
-            m = 'public Material '+var_name+" = new Material();\n"
+            m = 'public Material '+var_name+";\n"
             type_Var = "Material"
         elif code.__contains__(".get("):
             code = code.replace(".get("," ")
@@ -105,16 +119,14 @@ def define_auto(code):
             type_Var = var_dict.get(code2)
         var_name = var_name.replace(" ","")
         var_dict[var_name] = (type_Var)
-        var_dict_type[type_Var] = True
         javacode = javacode.replace("implements Listener{\n","implements Listener{\n"+'    '+m)
-        var_list.append(var_name)
     return javacode
 class space:
     def forfinish(code):
         global python_space
         global javacode
         global java_space
-        global howmany
+        global isreturnneed
         global check_list
         while not code.__contains__("    "*python_space):
             java_space -=1
@@ -239,16 +251,18 @@ class ArrayList:
             addition_list.append('java.util.ArrayList')
         global check_list
         global var_dict_type
-        var_dict_type['ArrayList'] = True
         check_list.append("define")
         self.type = typeof
     def add(self,something):
         global check_list    
         check_list.append("activity")
     def get(self,index):
+        global material1
         global player1
         if self.type == "player":
             return player1
+        elif self.type == "material":
+            return material1
     def size(self):
         pass
     def __contains__(self,something):
@@ -257,7 +271,7 @@ class ArrayList:
         module = inspect.getmodule(frame[0])
         filename = module.__file__
         if self.type != type(something):
-            raise Exception('compare thing type have to be same as type of list '+filename+'", line '+str(long)+',')
+            raise Exception('compare thing type have to be same as type of list '+filename+'", line '+str(whenerror)+',')
 class String:
     def __init__(self):
         global check_list
@@ -432,36 +446,36 @@ class Block:
         global world1
         return world1
 def time(when):
-    global n
-    n +=1
-    if n ==1:
+    global repeat_var
+    repeat_var +=1
+    if repeat_var ==1:
         global check_list
         check_list.append("while_time")
         return True
     else:
-        n = 0
+        repeat_var = 0
         return False
 def event(when):
     global event_name
     event_name = when
-    global n
-    n +=1
-    if n ==1:
+    global repeat_var
+    repeat_var +=1
+    if repeat_var ==1:
         global check_list
         check_list.append("while_event")
         return True
     else:
-        n = 0
+        repeat_var = 0
         return False
 def when(*test):
-    global k
-    k +=1
-    if k ==1:
+    global when_var
+    when_var +=1
+    if when_var ==1:
         global check_list
         check_list.append("if")
         return True
     else:
-        k = 0
+        repeat_var = 0
         return False
 def repeat(*var_name):
     if len(var_name) ==1:
@@ -486,14 +500,14 @@ def repeat(*var_name):
             g.append(material1)
             return g
 def command(some):
-    global n
-    n +=1
-    if n ==1:
+    global repeat_var
+    repeat_var +=1
+    if repeat_var ==1:
         global check_list
         check_list.append("command")
         return True
     else:
-        n = 0
+        repeat_var = 0
         return False       
 def tell():
     global check_list
@@ -502,8 +516,8 @@ def tell():
     check_list.append("tell")
 def distinguish_execution(code):
     code = str(code)
-    global long
-    long +=1
+    global whenerror
+    whenerror +=1
     if not code.__contains__("import"):
         no_blank_i = code.replace(" ","")
         if not no_blank_i[0] == "#":
@@ -592,6 +606,9 @@ class playerjoinevent:
         return "hello"
     def __init__(self):
         pass
+    def getPlayer(self):
+        global player1
+        return player1
     def setJoinMessage(self,message):
         global check_list
         check_list.append("activity")
@@ -718,7 +735,7 @@ def make(server,**setting):
     global check_list
     global check_list_var
     global javacode
-    global howmany
+    global isreturnneed
     check_list.append("make")
     while check_list[0] != 'init':
         del check_list[0]
@@ -732,24 +749,24 @@ def make(server,**setting):
     filename = module.__file__
     file = open(filename,"r")
     lines = file.readlines()
-    global long
+    global whenerror
     for code in lines:
         code = str(code)
         code = code.replace("when=", "")
         getvalue = distinguish_execution(code)
         if getvalue == True:
-            m = check_list[check_list_var]
+            m = check_list[0]
             code = space.forfinish(code)
-            if m != 'make' and howmany ==1:
-                howmany = 0
+            if m != 'make' and isreturnneed ==1:
+                isreturnneed = 0
                 code = space.forfinish(code)
-                howmany =1
+                isreturnneed =1
             code = code.replace("    ","")
             code = code.replace("\n","")
             if code.__contains__("if"):
-                raise Exception("I'm Sorry you can't use 'if' instead you can use 'while when():'"+'"'+filename+'", line '+str(long)+',')
+                raise Exception("I'm Sorry you can't use 'if' instead you can use 'while when():'"+'"'+filename+'", line '+str(whenerror)+',')
             elif code.__contains__("elif") or code.__contains__("else"):
-                raise Exception("I'm Sorry who can't use elif or else"+'"'+filename+'", line '+str(long)+',')
+                raise Exception("I'm Sorry who can't use elif or else"+'"'+filename+'", line '+str(whenerror)+',')
             elif m == 'init':
                 del check_list[0] 
                 javacode = space.getspace(javacode)
@@ -762,7 +779,7 @@ def make(server,**setting):
                     if not (code.__contains__("get(")):
                         if not code[len(code)-2:len(code)] == "()":
                             # raise ValueError("you have to set () in '"+code+"'\n")
-                            raise Exception('you should put () in "'+filename+'", line '+str(long)+',')
+                            raise Exception('you should put () in "'+filename+'", line '+str(whenerror)+',')
                 else:
                     if not var_list.__contains__("random"):
                         m = "public Random random = new Random();\n"
@@ -794,6 +811,8 @@ def make(server,**setting):
                 code = code.replace("getName","getName()")
                 code = code.replace("size","size()")
                 code = code.replace("Material","Type")
+                code = code.replace("getType","getType()")
+                code = code.replace("toString","toString()")
                 if code.__contains__("getX") or code.__contains__("getY") or code.__contains__("getZ"):
                     i1 = code.split("=")[0]
                     i2 = code.split("=")[1]
@@ -845,9 +864,9 @@ def make(server,**setting):
                     addition_list.append("org.bukkit.Bukkit")
                     r = 2*"    "
                     javacode = javacode.replace('public void onEnable(){\n', 'public void onEnable(){\n'+r+'Bukkit.getPluginManager().registerEvents(this,this);\n')
-                global test_value
-                test_value +=1
-                name = 'test'+str(test_value)
+                global event_value
+                event_value +=1
+                name = 'test'+str(event_value)
                 javacode += "    "*(java_space-1)
                 javacode += "    "
                 javacode += "@EventHandler\n"
@@ -900,7 +919,6 @@ def make(server,**setting):
                 javacode = javacode.replace("public class Main extends JavaPlugin implements Listener{\n",
                 "public class Main extends JavaPlugin implements Listener{\n"+'    '+m)
                 var_list.append(variable_name)
-                var_dict_type[middle_part] = True
             elif m == 'activity':
                 del check_list[0] 
                 code = code.replace(" ","")
@@ -911,7 +929,7 @@ def make(server,**setting):
                 code = code.replace("True","true")
                 code = code.replace("False","false")
                 if code.__contains__("setCancel") and Event_name == "PlayerJoinEvent":
-                    raise Exception('PlayerJoinEvent cannot put setCancel "'+filename+'", line '+str(long)+',')
+                    raise Exception('PlayerJoinEvent cannot put setCancel "'+filename+'", line '+str(whenerror)+',')
                 javacode += code +';\n'
             elif m == 'activity_message':
                 del check_list[0] 
@@ -920,7 +938,7 @@ def make(server,**setting):
                 javacode = space.getspace(javacode)
                 if not code.__contains__('"'):
                     if code.__contains__('()'):
-                        raise Exception('you should put only variable in "'+filename+'", line '+str(long)+',')
+                        raise Exception('you should put only variable in "'+filename+'", line '+str(whenerror)+',')
                     first_part = code.split("(")[1]
                     first_part = first_part.split(")")[0]
                     first_part = first_part.replace('"','')
@@ -928,7 +946,7 @@ def make(server,**setting):
                         g = int(first_part)
                     except Exception:
                         if not (var_dict.get(first_part) == "String") and not(var_dict.get(first_part) == "Integar"):
-                            raise Exception('you should put only String or int in "'+filename+'", line '+str(long)+',')
+                            raise Exception('you should put only String or int in "'+filename+'", line '+str(whenerror)+',')
                 code = code.replace(i1,i2)
                 code = code.replace(")",'+"")')
                 javacode += code+';\n'
@@ -1016,7 +1034,6 @@ def make(server,**setting):
                 del list_name_list[0]
                 python_space +=1
                 java_space +=1
-                var_dict_type[type_var] = True
             elif m == 'for_range':
                 del check_list[0] 
                 code = code.replace(" ","")
@@ -1066,7 +1083,7 @@ def make(server,**setting):
             elif m == 'command':
                 del check_list[0]
                 code = space.forfinish(code)
-                global comnum
+                global command_contain
                 code = code.replace(" ","")
                 code = code.replace('whilecommand(',"")
                 code = code.replace('):',"")
@@ -1074,7 +1091,7 @@ def make(server,**setting):
                 code = code.replace("'","")
                 sys.stdout.write(code)
                 name = 'onCommand'
-                comnum +=1
+                command_contain +=1
                 java_space =1
                 python_space = 0
                 if not javacode.__contains__('public boolean '+name+'(CommandSender sender, Command cmd, String Label, String[] args) {\n'):
@@ -1084,7 +1101,7 @@ def make(server,**setting):
                 python_space +=1
                 javacode += '    '*2+'if (Label.equalsIgnoreCase("'+code+'")) {\n'
                 java_space +=1
-                howmany =1
+                isreturnneed =1
                 if not addition_list.__contains__("org.bukkit.command.Command"): 
                     addition_list.append("org.bukkit.command.Command")
                     addition_list.append("org.bukkit.command.CommandSender")
@@ -1098,7 +1115,7 @@ def make(server,**setting):
                 filek.close()
             elif m == "make":
                 del check_list[0]
-                if howmany ==1:
+                if isreturnneed ==1:
                     while java_space > 0:
                         if java_space == 2:
                             javacode = space.getspace(javacode)
@@ -1111,24 +1128,6 @@ def make(server,**setting):
                         java_space -=1
                         javacode = space.getspace(javacode)
                         javacode += "}\n"
-    if var_dict_type.get("Location") == False:
-        addition_list.remove("org.bukkit.Location")
-    if Playerinclude == False:
-        addition_list.remove("org.bukkit.entity.Player")
-    if var_dict_type.get("ArrayList") == False:
-        addition_list.remove("java.util.ArrayList")
-    if var_dict_type.get("World") == False:
-        addition_list.remove("org.bukkit.World")
-    if var_dict_type.get("ItemStack") == False:
-        addition_list.remove("org.bukkit.inventory.ItemStack")
-    if var_dict_type.get("Action") == False:
-        addition_list.remove("org.bukkit.event.block.Action")
-    if var_dict_type.get("Material") == False:
-        addition_list.remove("org.bukkit.Material")
-    if var_dict_type.get("Inventory") == False:
-        addition_list.remove("org.bukkit.inventory.Inventory")
-    if var_dict_type.get("Block") == False:
-        addition_list.remove("org.bukkit.block.Block")
     addition = ""
     for code1 in addition_list:
         addition += 'import '+code1 +';\n'
@@ -1136,7 +1135,7 @@ def make(server,**setting):
     last_String = 'package Main;\n\n'+addition+javacode
     files.write(last_String)
     files.close()
-    minepy = "minepy"
+    minepy = "python minepy.py"
     if server == True:
         minepy += " -s"
     if port == True:
